linux-um archives
 help / color / mirror / Atom feed
* [uml-devel] [PATCH 2/7] UML - Fix skas0 stub return
@ 2005-07-28 16:26 Jeff Dike
  0 siblings, 0 replies; only message in thread
From: Jeff Dike @ 2005-07-28 16:26 UTC (permalink / raw)
  To: akpm; +Cc: linux-kernel, user-mode-linux-devel, Bodo Stroesser

From: Bodo Stroesser <bstroesser@fujitsu-siemens.com>

It's wrong to pop a fixed number of words from stack before
calling sigreturn, as the number depends on what code is generated
by the compiler for the start of stub_segv_handler().
What we need is esp containing the address of sigcontext. So we
explicitly load that pointer into esp.

Signed-off-by: Bodo Stroesser <bstroesser@fujitsu-siemens.com>
Signed-off-by: Jeff Dike <jdike@addtoit.com>

Index: linux-2.6.12-rc3-mm2/arch/um/sys-i386/stub_segv.c
===================================================================
--- linux-2.6.12-rc3-mm2.orig/arch/um/sys-i386/stub_segv.c	2005-07-27 17:22:18.000000000 -0400
+++ linux-2.6.12-rc3-mm2/arch/um/sys-i386/stub_segv.c	2005-07-28 10:35:18.000000000 -0400
@@ -21,10 +21,10 @@
 	__asm__("movl %0, %%eax ; int $0x80": : "g" (__NR_getpid));
 	__asm__("movl %%eax, %%ebx ; movl %0, %%eax ; movl %1, %%ecx ;"
 		"int $0x80": : "g" (__NR_kill), "g" (SIGUSR1));
 	/* Pop the frame pointer and return address since we need to leave
 	 * the stack in its original form when we do the sigreturn here, by
 	 * hand.
 	 */
-	__asm__("popl %%eax ; popl %%eax ; popl %%eax ; movl %0, %%eax ; "
-		"int $0x80" : : "g" (__NR_sigreturn));
+	__asm__("mov %0,%%esp ; movl %1, %%eax ; "
+		"int $0x80" : : "a" (sc), "g" (__NR_sigreturn));
 }



-------------------------------------------------------
SF.Net email is Sponsored by the Better Software Conference & EXPO September
19-22, 2005 * San Francisco, CA * Development Lifecycle Practices
Agile & Plan-Driven Development * Managing Projects & Teams * Testing & QA
Security * Process Improvement & Measurement * http://www.sqe.com/bsce5sf
_______________________________________________
User-mode-linux-devel mailing list
User-mode-linux-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/user-mode-linux-devel

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2005-07-28 16:34 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -21,10 +21,10 @@
 	__asm__("movl %%eax, %%ebx ; movl %0, %%eax ; movl %1, %%ecx ;"
 		"int $0x80": : "g" (__NR_kill), "g" (SIGUSR1));
-	/* Pop the frame pointer and return address since we need to leave
+	/* Load pointer to sigcontext into esp, since we need to leave
 	 * the stack in its original form when we do the sigreturn here, by
 	 * hand.
2005-07-28 16:26 [uml-devel] [PATCH 2/7] UML - Fix skas0 stub return Jeff Dike

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox